@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = '0.07';
+$VERSION = '0.08';
 
 #----------------------------------------------------------------------------
 
@@ -349,7 +349,7 @@ Outlook (R) installed.
 
 =head1 AUTHOR
 
-Barbie, C< <<barbie@cpan.org>> >
+Barbie, <barbie@cpan.org>
 for Miss Barbell Productions, L<http://www.missbarbell.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
